==> nativescript-4.0.0-2018-03-28-11309.tgz: package/docs/man_pages/project/configuration/resources/resources-generate-splashes.md <==
<% if (isJekyll) { %>---
title: tns resources generate splashes
position: 12
---<% } %>
# tns resources generate splashes

Usage | Synopsis
------|-------
`$ tns resources generate splashes <Path to image> [<background>]` | Generate all splashscreens for Android and iOS based on the specified image.

Generates all icons for Android and iOS platforms and places the generated images in the correct directories under `App_Resources/<platform>` directory.

### Attributes
* `<Path to image>` is a valid path to an image that will be used to generate all splashscreens.
* `<background>` is a valid path to an image that will be used as a background of the splashscreen. Defaults to white in case it is not specified.

<% if(isHtml) { %>
### Related Commands

Command | Description
----------|----------
[install](../install.html) | Installs all platforms and dependencies described in the `package.json` file in the current directory.
[platform add](../platform-add.html) | Configures the current project to target the selected platform.
[platform remove](../platform-remove.html) | Removes the selected platform from the platforms that the project currently targets.
[platform](../platform.html) | Lists all platforms that the project currently targets.
[prepare](../prepare.html) | Copies common and relevant platform-specific content from the app directory to the subdirectory for the selected target platform in the platforms directory.
[resources update](resources-update.md) | Updates the `App_Resources/Android` internal folder structure to conform to that of an Android Studio project.
[resources generate icons](resources-generate-icons.md) | Generates icons for Android and iOS.
<% } %>

==> nativescript-4.2.0-2018-07-19-12015.tgz: package/docs/man_pages/project/configuration/resources/resources-generate-splashes.md <==
<% if (isJekyll) { %>---
title: tns resources generate splashes
position: 12
---<% } %>
# tns resources generate splashes

Usage | Synopsis
------|-------
`$ tns resources generate splashes <Path to image> [--background <Color>]` | Generate all splashscreens for Android and iOS based on the specified image.

Generates all splashscreens for Android and iOS platforms and places the generated images in the correct directories under `App_Resources/<platform>` directory.

### Options
* `--background` Sets the background color of the splashscreen. Defaults to white in case it is not specified.

### Attributes
* `<Path to image>` is a valid path to an image that will be used to generate all splashscreens.
* `<Color>` is a valid color. It can be represented with string, like `white`, `black`, `blue`, etc. or its HEX representation, for example `#FFFFFF`, `#000000`, `#0000FF`. NOTE: As the `#` is special symbol in some terminals, make sure to place the value in quotes, for example `$ tns resources generate splashes ../myImage.png --background "#FF00FF"`.

<% if(isHtml) { %>
### Related Commands

Command | Description
----------|----------
[install](../install.html) | Installs all platforms and dependencies described in the `package.json` file in the current directory.
[platform add](../platform-add.html) | Configures the current project to target the selected platform.
[platform remove](../platform-remove.html) | Removes the selected platform from the platforms that the project currently targets.
[platform](../platform.html) | Lists all platforms that the project currently targets.
[prepare](../prepare.html) | Copies common and relevant platform-specific content from the app directory to the subdirectory for the selected target platform in the platforms directory.
[resources update](resources-update.md) | Updates the `App_Resources/Android` internal folder structure to conform to that of an Android Studio project.
[resources generate icons](resources-generate-icons.md) | Generates icons for Android and iOS.
<% } %>
